@@ -3,7 +3,7 @@ from __future__ import annotations
 import argparse
 from collections.abc import Sequence
 
-from fppull.aggregate_season import join_all_weeks, write_season_outputs
+from src.fppull.aggregate_season import join_all_weeks, write_season_outputs
 
 
 def parse_weeks(raw: str) -> list[int]:
